@@ -1,7 +1,7 @@
 import numpy as np
 # from earthquakepy import timeseries
 from .tsReaders import *
-from .ims import *
+# from .ims import *
 from .responseSdof import *
 from .responseMdof import *
 from .opensees_helper import *
